package pps.core.space.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import pps.core.space.entity.SpaceIntervalSystemEnt;
import pps.core.space.entity.SpaceIntervalSystemView;
import pps.core.space.mapper.SpaceIntervalSystemMapper;
import pps.core.space.mapper.SpaceIntervalSystemViewMapper;
import pps.core.space.service.data.space_interval_system.*;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.base.data.CustomQueryInput;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XPageResult;
import xstartup.data.XServiceResult;
import xstartup.data.XSingleResult;
import xstartup.error.XError;
import xstartup.feature.api.annotation.XApiAnonymous;
import xstartup.feature.api.annotation.XApiGet;
import xstartup.feature.api.annotation.XApiPost;
import xstartup.feature.mybatis.helper.XMapperHelper;

import java.util.List;

@XService
public class SpaceIntervalSystemService {
    @XApiAnonymous
    @XApiPost
    public XServiceResult createSpaceIntervalSystem(XContext context, CreateSpaceIntervalSystemInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        SpaceIntervalSystemEnt entity = new SpaceIntervalSystemEnt();
        XCopyUtils.copyObject(input, entity);
        mapper.insert(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult updateSpaceIntervalSystem(XContext context, UpdateSpaceIntervalSystemInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        QueryWrapper<SpaceIntervalSystemEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SpaceIntervalSystemEnt::getId, input.getId());
        SpaceIntervalSystemEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        XCopyUtils.copyObject(input, entity);
        mapper.updateById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult deleteSpaceIntervalSystem(XContext context, DeleteSpaceIntervalSystemInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        QueryWrapper<SpaceIntervalSystemEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SpaceIntervalSystemEnt::getId, input.getId());
        SpaceIntervalSystemEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        mapper.deleteById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetSpaceIntervalSystemOutput> getSpaceIntervalSystem(XContext context, GetSpaceIntervalSystemInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        QueryWrapper<SpaceIntervalSystemEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SpaceIntervalSystemEnt::getId, input.getId());
        SpaceIntervalSystemEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetSpaceIntervalSystemOutput output = new GetSpaceIntervalSystemOutput();
        XCopyUtils.copyObject(entity, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QuerySpaceIntervalSystemOutput> querySpaceIntervalSystem(XContext context, QuerySpaceIntervalSystemInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        QueryWrapper<SpaceIntervalSystemEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().like(SpaceIntervalSystemEnt::getId, input.getId())
                .eq(SpaceIntervalSystemEnt::getIsDeleted, input.getIsDeleted())
                .like(SpaceIntervalSystemEnt::getCreateById, input.getCreateById())
                .like(SpaceIntervalSystemEnt::getCreateByName, input.getCreateByName())
                .eq(SpaceIntervalSystemEnt::getCreateTime, input.getCreateTime())
                .like(SpaceIntervalSystemEnt::getModifyById, input.getModifyById())
                .like(SpaceIntervalSystemEnt::getModifyByName, input.getModifyByName())
                .eq(SpaceIntervalSystemEnt::getModifyTime, input.getModifyTime())
                .like(SpaceIntervalSystemEnt::getOuId, input.getOuId())
                .like(SpaceIntervalSystemEnt::getLineId, input.getLineId())
                .like(SpaceIntervalSystemEnt::getGridTypeKey, input.getGridTypeKey())
                .like(SpaceIntervalSystemEnt::getSystemName, input.getSystemName())
                .eq(SpaceIntervalSystemEnt::getSystemStartDate, input.getSystemStartDate())
                .eq(SpaceIntervalSystemEnt::getSystemEndDate, input.getSystemEndDate())
                .like(SpaceIntervalSystemEnt::getOptimizedTo, input.getOptimizedTo())
                .eq(SpaceIntervalSystemEnt::getIsCurrentRun, input.getIsCurrentRun());
        return XMapperHelper.query(mapper, input, queryWrapper, QuerySpaceIntervalSystemOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QuerySpaceIntervalSystemOutput> dynamicQuerySpaceIntervalSystem(XContext context, CustomQueryInput input) {
        SpaceIntervalSystemMapper mapper = context.getBean(SpaceIntervalSystemMapper.class);
        return XMapperHelper.query(mapper, input, SpaceIntervalSystemEnt.class, QuerySpaceIntervalSystemOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetSpaceIntervalSystemViewOutput> getSpaceIntervalSystemView(XContext context, GetSpaceIntervalSystemViewInput input) {
        SpaceIntervalSystemViewMapper mapper = context.getBean(SpaceIntervalSystemViewMapper.class);
        SpaceIntervalSystemView record = new SpaceIntervalSystemView();
        XCopyUtils.copyObject(input, record);
        SpaceIntervalSystemView view = mapper.selectOne(record);
        if (view == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetSpaceIntervalSystemViewOutput output = new GetSpaceIntervalSystemViewOutput();
        XCopyUtils.copyObject(view, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QuerySpaceIntervalSystemViewOutput> querySpaceIntervalSystemView(XContext context, QuerySpaceIntervalSystemViewInput input) {
        SpaceIntervalSystemViewMapper mapper = context.getBean(SpaceIntervalSystemViewMapper.class);
        SpaceIntervalSystemView record = new SpaceIntervalSystemView();
        XCopyUtils.copyObject(input, record);
        PageHelper.startPage(input.getPage(), input.getLimit());
        List<SpaceIntervalSystemView> list = mapper.selectList(record);
        PageInfo<SpaceIntervalSystemView> pageInfo = new PageInfo<>(list);
        List<QuerySpaceIntervalSystemViewOutput> outputs = XCopyUtils.copyNewList(pageInfo.getList(), QuerySpaceIntervalSystemViewOutput.class);
        return XPageResult.success(outputs, input, pageInfo.getTotal());
    }

}
